************************************************************************
*
* Jacob N. Shapiro & Nils B. Weidmann 2015
* Is the Phone Mightier than the Sword?
* Replication .do file
*
* The authors thank Tom Scherer for outstanding assistance with all aspects of this project.
*
* This file is divided into 6 parts.  
* Part 1 installs necessary Stata programs and MUST be run before creating the tables or figures.
* Parts 2-6 produce the tables and figures used in the paper as well as a few other useful things.
* The complete code for any table and figure can be run without running the entire part.
* Below is a complete listing of what is contained in each part and how the output is formatted. 
*
*
* PART 1 - Stata set up
*
* PART 2 
* Input: district_month_working_forces 
* Outputs:
*  Table1 (excel)
*  Table2 by panel(excel)
*  Table3 (excel)
*  TableA04 (stata output)
*  FigureA05 (PNG image)
*  FigureA06 (PNG image)
*  TableA10 (excel)
*  FigureA11 (PNG image)
*  TableA12 by panel(excel)
*  TableA13 (excel)
*  TableA15 by panel (excel)
*
* PART 3 
* Input: fullbuffers_20_15_4_12_working_new.dta (from one_file_prep)
* Outputs:
*  Table4 (excel)
*  Table5 (excel)
*  TableA09 (stata output)
*  TableA16 (excel)
*  TableA17 (excel)
*
* PART 4 
* Input: merged_tower_district_year 
* Outputs:
*  Figure2a and Figure2b (PNG images)
*  TableA08 by panel(excel)
*  FigureA07(PNG image)
*
* PART 5 
* Input: icasualties_cell_paper
* Output:
*  A14 calculations (stata output)
*  
* PART 6
* Input: fullbuffers_20_15_4_12_working_new.dta 
* Output:
*  Core site-level regressions run dropping all intermediate towers
*
************************************************************************



************************************************************************
* Part 1 - install necessary programs
************************************************************************

ssc install unique
ssc install outreg2
* ssc install coefplot
net install grc1leg,from( http://www.stata.com/users/vwiggins/)
set memory 1G


************************************************************************
* Part 2 
************************************************************************

*************
* Table 1 - Impact of Increased Cell Phone Coverage on Total Attacks - District/Month
*************

* Setup
use district_month_working_forces, clear
xtset distid t1

* Output Table_1
areg fd.p_S1 d.towercount , cluster(distid) a(half)
outreg2 using Table1, replace auto(3) less(1) ctitle("First Differences and Half FE") excel
areg fd.p_S1 d.towercount , cluster(distid) a(quarter)
outreg2 using Table1, auto(3) less(1) ctitle("FD and Quarter FE") excel
areg fd.p_S1 d.towercount , cluster(distid) a(month)
outreg2 using Table1, auto(3) less(1) ctitle("FD and Month FE") excel
areg fd.p_S1 d.towercount m_4-m_59, cluster(distid) a(distid)
outreg2 using Table1, auto(3) less(1) ctitle("FD and District and Month FE") excel
areg fd.p_S1 d.towercount , cluster(distid) a(s_h)
outreg2 using Table1, auto(3) less(1) ctitle("FD and Sect X Half FE") excel
areg fd.p_S1 d.towercount , cluster(distid) a(s_q)
outreg2 using Table1, auto(3) less(1) ctitle("FD and Sect X Quarter FE") excel
areg fd.p_S1 d.towercount , cluster(distid) a(p_q)
outreg2 using Table1, auto(3) less(1) ctitle("FD and Province X Quarter FE") excel

*************
* Table 2 - Impact of Increased Cell Phone Coverage by Attack Type
*************

* Setup
use district_month_working_forces, clear
xtset distid t1

* Output by Panel
** Panel A: Different kinds of attacks 
areg fd.p_S1 d.towercount m_4-m_59, cluster(distid) a(distid)
outreg2 using Table2_PanelA, replace auto(3) less(1) ctitle("All Attacks") excel
areg fd.p_df d.towercount m_4-m_59, cluster(distid) a(distid)
outreg2 using Table2_PanelA, auto(3) less(1) ctitle("Direct Fire") excel
areg fd.p_idf d.towercount m_4-m_59, cluster(distid) a(distid)
outreg2 using Table2_PanelA, auto(3) less(1) ctitle("Indirect Fire") excel
*areg fd.p_ied d.towercount m_4-m_59, cluster(distid) a(distid)
areg fdp_iedtotal d.towercount m_4-m_59, cluster(distid) a(distid)
outreg2 using Table2_PanelA, auto(3) less(1) ctitle("Total IED Attempts") excel
*areg fdp_iedclear d.towercount fdp_iedtotal m_4-m_59 if month>=561, cluster(distid) a(distid)
areg fd_iedcrat d.towercount m_4-m_59 if month>=561, cluster(distid) a(distid)
outreg2 using Table2_PanelA, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel

** Panel B: Different kinds of attacks with spatial lag of DV
areg fd.p_S1 d.towercount m_4-m_59 fd.p_lag_S1 , cluster(distid) a(distid)
outreg2 using Table2_PanelB, replace auto(3) less(1) ctitle("All Attacks") excel
areg fd.p_df d.towercount m_4-m_59 fd.p_lag_df , cluster(distid) a(distid)
outreg2 using Table2_PanelB, auto(3) less(1) ctitle("Direct Fire") excel
areg fd.p_idf d.towercount m_4-m_59 fd.p_lag_idf , cluster(distid) a(distid)
outreg2 using Table2_PanelB, auto(3) less(1) ctitle("Indirect Fire") excel
areg fdp_iedtotal d.towercount m_4-m_59 fd.p_lag_iedtotal , cluster(distid) a(distid)
outreg2 using Table2_PanelB, auto(3) less(1) ctitle("Total IED Attacks") excel
areg fd_iedcrat d.towercount m_4-m_59 fd.iedcrat_lag if month>=561, cluster(distid) a(distid)
outreg2 using Table2_PanelB, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel

** Panel C: Different kinds of attacks dropping 2008 (when Zain and others built fast while violence was going down)
areg fdp_S1 d.towercount m_4-m_59 if competitors==0, cluster(distid) a(distid)
outreg2 using Table2_PanelC, replace auto(3) less(1) ctitle("All Attacks") excel
areg fdp_df d.towercount m_4-m_59 if competitors==0, cluster(distid) a(distid)
outreg2 using Table2_PanelC, auto(3) less(1) ctitle("Direct Fire") excel
areg fdp_idf d.towercount m_4-m_59 if competitors==0, cluster(distid) a(distid)
outreg2 using Table2_PanelC, auto(3) less(1) ctitle("Indirect Fire") excel
areg fdp_iedtotal d.towercount m_4-m_59 if competitors==0, cluster(distid) a(distid)
outreg2 using Table2_PanelC, auto(3) less(1) ctitle("Total IED Attempts") excel
areg fd_iedcrat d.towercount m_4-m_59 if competitors==0, cluster(distid) a(distid)
outreg2 using Table2_PanelC, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel

** Panel D: Different kinds of attacks with period-specific District FE
areg fdp_S1 d.towercount m_4-m_59 , cluster(distid) a(per_dis)
outreg2 using Table2_PanelD, replace auto(3) less(1) ctitle("All Attacks") excel
areg fdp_df d.towercount m_4-m_59 , cluster(distid) a(per_dis)
outreg2 using Table2_PanelD, auto(3) less(1) ctitle("Direct Fire") excel
areg fdp_idf d.towercount m_4-m_59 , cluster(distid) a(per_dis)
outreg2 using Table2_PanelD, auto(3) less(1) ctitle("Indirect Fire") excel
areg fdp_iedtotal d.towercount m_4-m_59 , cluster(distid) a(per_dis)
outreg2 using Table2_PanelD, auto(3) less(1) ctitle("Total IED Attempts") excel
areg fd_iedcrat d.towercount m_4-m_59 , cluster(distid) a(per_dis)
outreg2 using Table2_PanelD, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel

** Panel E: Different kinds of attacks controlling for Coalition Force levels
xtset distname month, monthly
areg fd.p_S1 d.towercount d.a_of_batt m_4-m_59, cluster(distid) a(distid)
outreg2 using Table2_PanelE, replace auto(3) less(1) ctitle("All Attacks") excel
areg fd.p_df d.towercount d.a_of_batt m_4-m_59, cluster(distid) a(distid)
outreg2 using Table2_PanelE, auto(3) less(1) ctitle("Direct Fire") excel
areg fd.p_idf d.towercount d.a_of_batt m_4-m_59, cluster(distid) a(distid)
outreg2 using Table2_PanelE, auto(3) less(1) ctitle("Indirect Fire") excel
areg fdp_iedtotal d.towercount d.a_of_batt m_4-m_59, cluster(distid) a(distid)
outreg2 using Table2_PanelE, auto(3) less(1) ctitle("Total IED Attempts") excel
areg fd_iedcrat d.towercount d.a_of_batt  m_4-m_59 , cluster(distid) a(distid)
outreg2 using Table2_PanelE, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel


*************
* Table 3 - Impact of Increased Cell Phone Coverage by Sectarian Area
*************

* Setup
use district_month_working_forces, clear
xtset distid t1

* Output Table3
areg fd.p_S1 d.towercount m_4-m_59, cluster(distid) a(distid)
outreg2 using Table3, replace auto(3) less(1) ctitle("All Areas") excel
areg fd.p_S1 d.towercount m_4-m_59 if sect2==1, cluster(distid) a(distid)
outreg2 using Table3,  auto(3) less(1) ctitle("Mixed") excel
areg fd.p_S1 d.towercount m_4-m_59 if sect2==2, cluster(distid) a(distid)
outreg2 using Table3,  auto(3) less(1) ctitle("Kurd/Shia") excel
areg fd.p_S1 d.towercount m_4-m_59 if sect2==3, cluster(distid) a(distid)
outreg2 using Table3,  auto(3) less(1) ctitle("Sunni") excel
areg fd.p_S1 d.towercount m_4-m_59 if sect2==3 | sect2==1 , cluster(distid) a(distid)
outreg2 using Table3,  auto(3) less(1) ctitle("Mixed/Sunni") excel
areg fd.p_S1 d.towercount m_4-m_59 if homo==1, cluster(distid) a(distid)
outreg2 using Table3, auto(3) less(1) ctitle("Ethnically Homogenous") excel
areg fd.p_S1 d.towercount m_4-m_59 if homo==0, cluster(distid) a(distid)
outreg2 using Table3, auto(3) less(1) ctitle("Non-Homogenous") excel

*************
* A04 - Table: Descriptive statistics for the district-level data
*************

* setup
use district_month_working_forces, clear
xtset distid t1

* output (formatted to produce TableA04)
** Panel A: Violence Variables
summ p_all p_S1 p_df p_iedtotal p_sec_min p_sec4_min

** Panel B: Control Variables
summ newtowers towercount pop 
summ sunni_prop shia_prop if month==529



*************
* A05 - Figure: Patterns of violence and network expansion across Iraq's 20 most violent districts
*************

* Setup
use district_month_working_forces, clear
xtset distid t1
drop if totalevents < 1300
drop if district=="Tarmia" | district=="Basrah" 

* Output FigureA05
twoway (tsline p_all) (tsline newtowers, yaxis(2)), ///
	ytitle(Monthly Incidents Per 1000 People) ///
	ytitle(, size(small)) ///
	ylabel(, labsize(vsmall)) ///
	ytitle(New Tower Installations, axis(2)) ///
	ytitle(, size(small) orientation(vertical) axis(2)) ///
	ylabel(, labsize(vsmall) axis(2)) ///
	ttitle(Month) ttitle(, size(small)) tlabel(529(12)588, format(%tmYY) labsize(vsmall)) ///
	by(, title(Attacks and Cell Tower Installations, size(small)) ///
	subtitle((Feb. 2004 - Feb. 2009), size(vsmall))) ///
	legend(order(1 "Insurgent Attacks (left axis)" 2 "New Towers (right axis)") ///
	rows(1) size(vsmall)) ///
	by(district, note("Note: Select districts with over 1,300 total events.",size(vsmall))) ///
	scheme(s1color)
graph export FigureA05.png 

*************
* A06 - Figure: National trends in violence and network expansion 
*************

* Setup
use district_month_working_forces, clear
xtset distid t1
bys t1: egen mean_p_S1 = mean(p_S1)

* Output FigureA06
twoway line mean_p_S1 t1 if distid==13, xlabel(none) xtick(529(6)588) xtitle(,size(zero)) ytitle(Mean Combat Events per 1000) name(events, replace) scheme(s1color)
twoway line sum_newtowers t1 if distid==13, xtitle(,size(zero)) xlabel(529(6)588, format(%tmMon-YY) nogrid) ytitle(New Towers Nationwide) name(towers, replace) scheme(s1color)
graph combine events towers, col(1) name(events_towers, replace) title(Tower Introductions and Violence, size(medium)) ///
	scheme(s1color)
graph export FigureA06.png

*************
* A10 - Table: Regression results with spatial lag
*************

* Setup
use district_month_working_forces, clear
xtset distid t1

* Output TableA10
areg fd.p_S1 d.towercount fd.p_lag_S1 , cluster(distid) a(half)
outreg2 using TableA10, replace auto(3) less(1) ctitle("First Differences and Half FE") excel
areg fd.p_S1 d.towercount fd.p_lag_S1 , cluster(distid) a(quarter)
outreg2 using TableA10, auto(3) less(1) ctitle("FD and Quarter FE") excel
areg fd.p_S1 d.towercount fd.p_lag_S1 , cluster(distid) a(month)
outreg2 using TableA10, auto(3) less(1) ctitle("FD and Month FE") excel
areg fd.p_S1 d.towercount fd.p_lag_S1  m_4-m_59, cluster(distid) a(distid)
outreg2 using TableA10, auto(3) less(1) ctitle("FD and District and Month FE") excel
areg fd.p_S1 d.towercount fd.p_lag_S1 , cluster(distid) a(s_h)
outreg2 using TableA10, auto(3) less(1) ctitle("FD and Sect X Half FE") excel
areg fd.p_S1 d.towercount fd.p_lag_S1 , cluster(distid) a(s_q)
outreg2 using TableA10, auto(3) less(1) ctitle("FD and Sect X Quarter FE") excel
areg fd.p_S1 d.towercount fd.p_lag_S1 , cluster(distid) a(p_q)
outreg2 using TableA10, auto(3) less(1) ctitle("FD and Province X Quarter FE") excel

*************
* A11 - Figure: District-level effects over time
*************

* Setup
use district_month_working_forces, clear
xtset distid t1
replace dtow = d.towercount
gen dp_S1 = d.p_S1
forval x = 1(1)7 {
	gen l`x'dp_S1 = l`x'd.p_S1
	gen f`x'dp_S1 = f`x'd.p_S1
	}
local time "l5d l4d l3d l2d l1d d f1d f2d f3d f4d f5d f6d f7d"
foreach x of local time {
	qui areg `x'p_S1 dtow m_4-m_59, cluster(distid) a(distid) level(90)
	est store `x'
	}

* Output FigureA11, amendments made in editor
coefplot l5d || l4d || l3d || l2d || l1d || d || f1d || f2d || f3d || f4d || f5d || f6d || f7d, ///
	keep(dtow) vertical scheme(s1mono) level(90) legend(off) bycoefs ///
	xtitle(Months relative to tower installation, size(small)) ytitle(Incidents, size(small)) title(Change in incidents per 1000 per month from an additional tower in t=0, size(small)) ///
	yline(0)  
graph export FigureA11.png
	
	
*************
* A12 - Checking for omitted variable bias in the tower-level resutls
*************

* Setup
use district_month_working_forces, clear
xtset distid t1

* Output by Panel
** Panel A: Temporal placebo tests
areg ld.p_S1 d.towercount , cluster(distid) a(half)
outreg2 using TableA12_PanelA, replace auto(3) less(1) ctitle("First Differences and Half FE") excel
areg ld.p_S1 d.towercount , cluster(distid) a(quarter)
outreg2 using TableA12_PanelA, auto(3) less(1) ctitle("FD and Quarter FE") excel
areg ld.p_S1 d.towercount , cluster(distid) a(month)
outreg2 using TableA12_PanelA, auto(3) less(1) ctitle("FD and Month FE") excel
areg ld.p_S1 d.towercount m_4-m_59, cluster(distid) a(distid)
outreg2 using TableA12_PanelA, auto(3) less(1) ctitle("FD and District and Month FE") excel
areg ld.p_S1 d.towercount , cluster(distid) a(s_h)
outreg2 using TableA12_PanelA, auto(3) less(1) ctitle("FD and Sect X Half FE") excel
areg ld.p_S1 d.towercount , cluster(distid) a(s_q)
outreg2 using TableA12_PanelA, auto(3) less(1) ctitle("FD and Sect X Quarter FE") excel
areg ld.p_S1 d.towercount , cluster(distid) a(p_q)
outreg2 using TableA12_PanelA, auto(3) less(1) ctitle("FD and Province X Quarter FE") excel

** Panel B: Geographic placebo tests
areg fd.p_lag_S1 d.towercount , cluster(distid) a(half)
outreg2 using TableA12_PanelB, replace auto(3) less(1) ctitle("First Differences and Half FE") excel
areg fd.p_lag_S1 d.towercount , cluster(distid) a(quarter)
outreg2 using TableA12_PanelB, auto(3) less(1) ctitle("FD and Quarter FE") excel
areg fd.p_lag_S1 d.towercount , cluster(distid) a(month)
outreg2 using TableA12_PanelB, auto(3) less(1) ctitle("FD and Month FE") excel
areg fd.p_lag_S1 d.towercount m_4-m_59, cluster(distid) a(distid)
outreg2 using TableA12_PanelB, auto(3) less(1) ctitle("FD and District and Month FE") excel
areg fd.p_lag_S1 d.towercount , cluster(distid) a(s_h)
outreg2 using TableA12_PanelB, auto(3) less(1) ctitle("FD and Sect X Half FE") excel
areg fd.p_lag_S1 d.towercount , cluster(distid) a(s_q)
outreg2 using TableA12_PanelB, auto(3) less(1) ctitle("FD and Sect X Quarter FE") excel
areg fd.p_lag_S1 d.towercount , cluster(distid) a(p_q)
outreg2 using TableA12_PanelB, auto(3) less(1) ctitle("FD and Province X Quarter FE") excel

*************
* A13 - Checking for the direct impact of violence on future tower construction
*************

* Setup
use district_month_working_forces, clear
xtset distid t1

* Output TableA13
** Panel A: Core specification
areg fd.p_S1 d.towercount d.p_sec_min, cluster(distid) a(month)
outreg2 using TableA13, replace auto(3) less(1) ctitle("Panel A: Sectarian and Month FE") excel
areg fd.p_S1 d.towercount m_4-m_59 d.p_sec_min, cluster(distid) a(distid)
outreg2 using TableA13, auto(3) less(1) ctitle("Panel A: Sectarian and District and Month FE") excel
** Panel B: Controls for total sectarian violence
areg fd.p_S1 d.towercount m_4-m_59 d.p_sec_min ld.p_sec_min , cluster(distid) a(distid)
outreg2 using TableA13, auto(3) less(1) ctitle("Panel B: 2 Lags of Sectarian") excel
areg fd.p_S1 d.towercount m_4-m_59 d.p_sec_min ld.p_sec_min l2d.p_sec_min , cluster(distid) a(distid)
outreg2 using TableA13, auto(3) less(1) ctitle("Panel B: 3 Lags of Sectarian") excel
areg fd.p_S1 d.towercount m_4-m_59 lma_p_sec_min , cluster(distid) a(distid)
outreg2 using TableA13, auto(3) less(1) ctitle("Panel B: Lagged Moving Average of Sectarian") excel
** Panel C: Controls for targeted killings by sectarian militias
areg fd.p_S1 d.towercount m_4-m_59 d.p_sec4_min ld.p_sec4_min , cluster(distid) a(distid)
outreg2 using TableA13, auto(3) less(1) ctitle("Panel C: 2 Lags of Sectarian") excel
areg fd.p_S1 d.towercount m_4-m_59 d.p_sec4_min ld.p_sec4_min l2d.p_sec4_min , cluster(distid) a(distid)
outreg2 using TableA13, auto(3) less(1) ctitle("Panel C: 3 Lags of Sectarian") excel
areg fd.p_S1 d.towercount m_4-m_59 lma_p_sec4_min  , cluster(distid) a(distid)
outreg2 using TableA13, auto(3) less(1) ctitle("Panel C: Lagged Moving Average of Sectarian") excel

*************
* A14 - Checking for changes in insurgent effectiveness caused by cell phone coverage
*************

* NEEDED

*************
* A15 - District-level results by attack type and sectarian region
*************

* Setup
use district_month_working_forces, clear
xtset distid t1

* Output by Panel

** Panel A: Mixed Areas
areg fd.p_S1 d.towercount m_4-m_59 if sect2==1, cluster(distid) a(distid)
outreg2 using TableA15_PanelA, replace auto(3) less(1) ctitle("All Attacks") excel
areg fd.p_df d.towercount m_4-m_59 if sect2==1, cluster(distid) a(distid)
outreg2 using TableA15_PanelA, auto(3) less(1) ctitle("Direct Fire") excel
areg fd.p_idf d.towercount m_4-m_59 if sect2==1, cluster(distid) a(distid)
outreg2 using TableA15_PanelA, auto(3) less(1) ctitle("Indirect Attacks") excel
areg fd.p_iedtotal d.towercount m_4-m_59 if sect2==1, cluster(distid) a(distid)
outreg2 using TableA15_PanelA, auto(3) less(1) ctitle("IED Attempts") excel
areg fd_iedcrat dtow m_4-m_59 if sect2==1 & month>=561, cluster(distid) a(distid)
outreg2 using TableA15_PanelA, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel

** Panel B: Kurdish/Shia Areas
areg fd.p_S1 d.towercount m_4-m_59 if sect2==2, cluster(distid) a(distid)
outreg2 using TableA15_PanelB, replace auto(3) less(1) ctitle("All Attacks") excel
areg fd.p_df d.towercount m_4-m_59 if sect2==2, cluster(distid) a(distid)
outreg2 using TableA15_PanelB, auto(3) less(1) ctitle("Direct Fire") excel
areg fd.p_idf d.towercount m_4-m_59 if sect2==2, cluster(distid) a(distid)
outreg2 using TableA15_PanelB, auto(3) less(1) ctitle("Indirect Attacks") excel
areg fd.p_iedtotal d.towercount m_4-m_59 if sect2==2, cluster(distid) a(distid)
outreg2 using TableA15_PanelB, auto(3) less(1) ctitle("IED Attempts") excel
areg fd_iedcrat dtow m_4-m_59 if sect2==2 & month>=561, cluster(distid) a(distid)
outreg2 using TableA15_PanelB, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel

** Panel C: Sunni Areas
areg fd.p_S1 d.towercount m_4-m_59 if sect2==3, cluster(distid) a(distid)
outreg2 using TableA15_PanelC, replace auto(3) less(1) ctitle("All Attacks") excel
areg fd.p_df d.towercount m_4-m_59 if sect2==3, cluster(distid) a(distid)
outreg2 using TableA15_PanelC, auto(3) less(1) ctitle("Direct Fire") excel
areg fd.p_idf d.towercount m_4-m_59 if sect2==3, cluster(distid) a(distid)
outreg2 using TableA15_PanelC, auto(3) less(1) ctitle("Indirect Attacks") excel
areg fd.p_iedtotal d.towercount m_4-m_59 if sect2==3, cluster(distid) a(distid)
outreg2 using TableA15_PanelC, auto(3) less(1) ctitle("IED Attempts") excel
areg fd_iedcrat dtow m_4-m_59 if sect2==3 & month>=561, cluster(distid) a(distid)
outreg2 using TableA15_PanelC, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel

** Panel D: Mixed and Sunni Areas Combined
areg fd.p_S1 d.towercount m_4-m_59 if sect2==1 | sect2==3, cluster(distid) a(distid)
outreg2 using TableA15_PanelD, replace auto(3) less(1) ctitle("All Attacks") excel
areg fd.p_df d.towercount m_4-m_59 if sect2==1 | sect2==3, cluster(distid) a(distid)
outreg2 using TableA15_PanelD, auto(3) less(1) ctitle("Direct Fire") excel
areg fd.p_idf d.towercount m_4-m_59 if sect2==1 | sect2==3, cluster(distid) a(distid)
outreg2 using TableA15_PanelD, auto(3) less(1) ctitle("Indirect Attacks") excel
areg fd.p_iedtotal d.towercount m_4-m_59 if sect2==1 | sect2==3, cluster(distid) a(distid)
outreg2 using TableA15_PanelD, auto(3) less(1) ctitle("IED Attempts") excel
areg fd_iedcrat dtow m_4-m_59 if (sect2==1 | sect2==3) & month>=561, cluster(distid) a(distid)
outreg2 using TableA15_PanelD, auto(3) less(1) ctitle("IEDs Cleared / Total Attempts") excel


************************************************************************
* Part 3
************************************************************************

*************
* Table 4 - Impact of Introducing Cellular Communications for Tower Areas
*************

use fullbuffers_20_15_4_12_working_new.dta, clear

* Standard Difference-in-Differences with Site FE
areg eventcount_S1 after aftnew10 , cluster(siteid) a(siteid)
outreg2 using Table4, replace auto(3) less(1) ctitle("PanelA_10%") excel
forval x = 3(2)9 {
	display "Dif-in-dif with site FE at `x'0% new"
	areg eventcount_S1 after aftnew`x'0 , cluster(siteid) a(siteid)
	outreg2 using Table4, auto(3) less(1) ctitle("PanelA_`x'0%") excel
	}

* Adding Quarter FE to Control for Secular Trends
areg eventcount_S1 after aftnew10 q_5-q_24 , cluster(siteid) a(siteid)	 	
outreg2 using Table4, auto(3) less(1) ctitle("PanelB_10%") excel drop(q_*)
forval x = 3(2)9 {
	display "Dif-in-dif with site and quarter FE"	
	areg eventcount_S1 after aftnew`x'0 q_5-q_24 , cluster(siteid) a(siteid) 	
	outreg2 using Table4, auto(3) less(1) ctitle("PanelB_`x'0%") excel drop(q_*)
	}

*************
* Table 5 - Impact of Increased Cell Phone Coverage by Attack Type at Different Thresholds
*************

use fullbuffers_20_15_4_12_working_new.dta, clear

* Tower Level Results by Attack Type
* Repeat for attack types at the 20%, 50%, and 80% thresholds
* note that in the output "S1" refers to "All Attacks"

local type "S1 df idf iedtot"
local size "2 5 8"
local replacer = 1

foreach x of local size {
	foreach y of local type {
		
		areg eventcount_`y' after aftnew`x'0 q_5-q_24 , cluster(siteid) a(siteid)	 	
		outreg2 using Table5, auto(3) less(1) ctitle("`y', `x'0%") excel drop(q_*)
			
		while `replacer' == 1 {
			areg eventcount_`y' after aftnew`x'0 q_5-q_24 , cluster(siteid) a(siteid)	 	
			outreg2 using Table5, replace auto(3) less(1) ctitle("`y', `x'0%") excel drop(q_*)
			local replacer = 0
			continue
			}
		}
	}
	

*************
* A09 - Table: Descriptive Statistics for the tower-level data
*************

* setup
use fullbuffers_20_15_4_12_working_new.dta, clear

* output (formatted to produce TableA09)
** Panel A: Violence Variables - Full Sample
summ eventcount_S1 eventcount_df eventcount_idf eventcount_iedtot if using_area==1
** Panel B: Tower Areas Characteristics - Full Sample
summ totarea propnew totpop urban sunni_prop shia_prop if using_area==1 & period==0
** Panel C: Violence Variables - Less than 50% New
summ eventcount_S1 eventcount_df eventcount_idf eventcount_iedtot if using_area==1 & propnew<.5
** Panel D: Tower Areas Characteristics - Less than 50% New
summ totarea propnew totpop urban sunni_prop shia_prop if using_area==1 & period==0 & propnew<.5
** Panel E: Violence Variables - More than 50% New
summ eventcount_S1 eventcount_df eventcount_idf eventcount_iedtot if using_area==1 & propnew>=.5
** Panel F: Tower Areas Characteristics - More than 50% New
summ totarea propnew totpop urban sunni_prop shia_prop if using_area==1 & period==0 & propnew>=.5


*************
* A16 - Table: Tower-level results by attack type and period
*************

use fullbuffers_20_15_4_12_working_new.dta, clear

* Dropping middle 
areg eventcount_S1 after aftnew20 q_5-q_24 if on_m<tm(2006m7) | on_m>tm(2007m8), cluster(siteid) a(siteid)
	lincom after+aftnew20
	scalar def stane= r(se)
outreg2 using TableA16, addstat("Total Effect of New Tower", r(estimate), SE, stane)  replace auto(3) less(1) ctitle("S1_dropmid") excel drop(q_*)	
local vars "df idf iedtot"
foreach x of local vars {
	areg eventcount_`x' after aftnew20 q_5-q_24 if on_m<tm(2006m7) | on_m>tm(2007m8), cluster(siteid) a(siteid)
		lincom after+aftnew20
		scalar def stane= r(se)
		outreg2 using TableA16, addstat("Total Effect of New Tower", r(estimate), SE, stane) append auto(3) less(1) ctitle("`x'_dropmid") excel drop(q_*)
	}

* Dropping 2008 (added to same excel)
areg eventcount_S1 after aftnew20 q_5-q_21 if on_m<tm(2008m1), cluster(siteid) a(siteid)
	lincom after+aftnew20
	scalar def stane= r(se)
outreg2 using TableA16, addstat("Total Effect of New Tower", r(estimate), SE, stane)  auto(3) less(1) ctitle("S1_no2008") excel	drop(q_*)
local vars "df idf iedtot"
foreach x of local vars {
	areg eventcount_`x' after aftnew20 q_5-q_21 if on_m<tm(2008m1), cluster(siteid) a(siteid)
		lincom after+aftnew20
		scalar def stane= r(se)
		outreg2 using TableA16, addstat("Total Effect of New Tower", r(estimate), SE, stane) append auto(3) less(1) ctitle("`x'_no2008") excel drop(q_*)
	}

*************
* A17 - Table: Tower-level results by urban/rural towers
*************

use fullbuffers_20_15_4_12_working_new.dta, clear

egen rtS1 = rowtotal(ring0_S1-ring3_S1) /* Generate spillover variable*/ 

areg rtS1 after aftnew10 q_5-q_24 , cluster(siteid) a(siteid)	 	
outreg2 using TableA17, replace auto(3) less(1) ctitle("PanelA_10") excel drop(q_*)
forval x = 3(2)9 {
	display "Ring Dif-in-dif with site and quarter FE"	
	areg rtS1 after aftnew`x'0 q_5-q_24 , cluster(siteid) a(siteid) 	
	outreg2 using TableA17, auto(3) less(1) ctitle("PanelA_`x'0") excel drop(q_*)
	}

forval x = 1(2)9 {
	display "Ring Dif-in-dif with site and quarter FE, controlling for within coverage area events"	
	areg rtS1 after eventcount_S1 aftnew`x'0 q_5-q_24 , cluster(siteid) a(siteid) 	
	outreg2 using TableA17, auto(3) less(1) ctitle("PanelB_`x'0") excel drop(q_*)
	}
	
	
************************************************************************
* Part 4 
************************************************************************

*************
* Figure 2 - Relationship between Violence and Tower Construction at District/Month
* A07 - Figure: Tower construction and violence in the last six months of current year
*************

* Setup
use merged_tower_district_year, clear

* Output - Figure 2a, Figure 2b, Figure A07
* (Figure 2's decimals is edited manually)

local var "mean"
local date "jan_jun july_dec july_dec_current"
local pnum = 1
local gphtitle = "Tower Construction and Violence in the First Six Months of Current Year"
local gphylab = "Incidents per 100000 population in the first six months of the current year"

foreach y of local var{
	foreach x of local date{
		local replacer = 1
		forval p = 2005/2008{
			* Grab the slope coefficient and t-stat
			regress `x'_agg_event tower_`y' if year==`p', rob
			local a = int(_b[tower_`y']*100)/100
			local b = int(_se[tower_`y']*100)/100
			* Get the height for the slope and se
			qui summarize `x'_agg_event if zero_tow==0 & year==`p', detail
			local z = r(max)*.8
			
			graph twoway ( ///
				lfitci `x'_agg_event tower_`y' if zero_tow==0 & year==`p', ///
				xlabel(1(1)12) text(`z' 10 "B =`a', SE = `b'", size(medsmall)) fintensity(inten20) ///
				) ///
				( ///
				scatter `x'_agg_event tower_`y' [aw=tot_built] if zero_tow==0 & year==`p', xscale(range(1 12)) ///
				mlwidth(vthin) msize(vsmall) msymbol(Oh) xtitle(Tower `y' per Year) ///
				), ///
				title(`p') legend(label(3 "District, sized by number of towers built in year") size(small)) ///
				saving(`x'_tower_`y'_`p'_ci.gph, replace) scheme(s1color)
			}

	grc1leg `x'_tower_`y'_2005_ci.gph `x'_tower_`y'_2006_ci.gph `x'_tower_`y'_2007_ci.gph `x'_tower_`y'_2008_ci.gph, ///
	title(`gphtitle', size(small)) l2title(`gphylab', size(vsmall)) ///
	iscale(.5) name(`x'_`y'_combined, replace) scheme(s1color)
	
	while `replacer' == 1 & `pnum' == 1 {
		graph export Figure2a.png, replace
		local gphtitle = "Tower Construction and Violence in the Last Six Months of Current Year"
		local gphylab = "Incidents per 100000 population in the first six months of the current year"
		local replacer = 0
		local pnum = 2
		continue
		}
	
	while `replacer' == 1 & `pnum' == 2  {
		graph export Figure2b.png, replace
		local gphtitle = "Tower Construction and Violence in the Last Six Months of Current Year"
		local gphylab = "Incidents per 100000 in the last six months of the current year"
		local replacer = 0
		local pnum = 3
		continue
		}
	
	while `replacer' == 1 & `pnum' == 3  {
		graph export FigureA07.png, replace
		local replacer = 0
		continue
		}
	}
}


*************
* A08 - Figure: Relationship between violence and average month of tower introduction
*************

* Setup
use merged_tower_district_year, clear

* Outputs: TableA08_Panel1, TableA08_Panel2, TableA08_Panel3
** Panel 1A
reg july_dec_agg_event tower_mean, rob
outreg2 using TableA08_Panel1, replace auto(3) less(1) ctitle("1A: Full Sample") excel
reg july_dec_agg_event tower_mean if year==2005, rob 
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1A: 2005") excel
reg july_dec_agg_event tower_mean if year==2006, rob
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1A: 2006") excel
reg july_dec_agg_event tower_mean if year==2007, rob
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1A: 2007") excel
reg july_dec_agg_event tower_mean if year==2008, rob
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1A: 2008") excel

** Panel 1B
reg july_dec_agg_event tower_mean s2_2-s2_3 , cluster(sect2)
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1B: Full Sample") excel
reg july_dec_agg_event tower_mean s2_2-s2_3 if year==2005 , cluster(sect2)
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1B: 2005") excel
reg july_dec_agg_event tower_mean s2_2-s2_3 if year==2006 , cluster(sect2)
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1B: 2006") excel
reg july_dec_agg_event tower_mean s2_2-s2_3 if year==2007 , cluster(sect2)
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1B: 2007") excel
reg july_dec_agg_event tower_mean s2_2-s2_3 if year==2008 , cluster(sect2)
outreg2 using TableA08_Panel1, auto(3) less(1) ctitle("1B: 2008") excel

** Panel 2A
reg jan_jun_agg_event tower_mean , rob
outreg2 using TableA08_Panel2, replace auto(3) less(1) ctitle("2A: Full Sample") excel
reg jan_jun_agg_event tower_mean if year==2005 , rob
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2A: 2005") excel
reg jan_jun_agg_event tower_mean if year==2006 , rob
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2A: 2006") excel
reg jan_jun_agg_event tower_mean if year==2007 , rob
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2A: 2007") excel
reg jan_jun_agg_event tower_mean if year==2008 , rob
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2A: 2008") excel

** Panel 2B
reg jan_jun_agg_event tower_mean s2_2-s2_3 , cluster(sect2)
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2B: Full Sample") excel
reg jan_jun_agg_event tower_mean s2_2-s2_3 if year==2005 , cluster(sect2)
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2B: 2005") excel
reg jan_jun_agg_event tower_mean s2_2-s2_3 if year==2006 , cluster(sect2)
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2B: 2006") excel
reg jan_jun_agg_event tower_mean s2_2-s2_3 if year==2007 , cluster(sect2)
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2B: 2007") excel
reg jan_jun_agg_event tower_mean s2_2-s2_3 if year==2008 , cluster(sect2)
outreg2 using TableA08_Panel2, auto(3) less(1) ctitle("2B: 2008") excel

** Panel 3A
reg july_dec_current_agg_event tower_mean 
outreg2 using TableA08_Panel3, replace auto(3) less(1) ctitle("3A: Full Sample") excel
reg july_dec_current_agg_event tower_mean if year==2005 , rob
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3A: 2005") excel
reg july_dec_current_agg_event tower_mean if year==2006 , rob
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3A: 2006") excel
reg july_dec_current_agg_event tower_mean if year==2007 , rob
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3A: 2007") excel
reg july_dec_current_agg_event tower_mean if year==2008 , rob
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3A: 2008") excel

** Panel 3B
reg july_dec_current_agg_event tower_mean s2_2-s2_3 , cluster(sect2)
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3B: Full Sample") excel
reg july_dec_current_agg_event tower_mean s2_2-s2_3 if year==2005 , cluster(sect2)
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3B: 2005") excel
reg july_dec_current_agg_event tower_mean s2_2-s2_3 if year==2006 , cluster(sect2)
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3B: 2006") excel
reg july_dec_current_agg_event tower_mean s2_2-s2_3 if year==2007 , cluster(sect2)
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3B: 2007") excel
reg july_dec_current_agg_event tower_mean s2_2-s2_3 if year==2008 , cluster(sect2)
outreg2 using TableA08_Panel3, auto(3) less(1) ctitle("3B: 2008") excel


************************************************************************
* Part 5
************************************************************************

*************
* A14 Calculations - Checking for changes in insurgent effectiveness caused by cell phone coverage
*************

* Setup
use "icasualties_cell_paper.dta", clear

* Output:

* correlation for entire timespan, .61
pwcorr icas sigacts_s1

* correlations:
* 2004 .70
* 2005 .51
* 2006 .55
* 2007 .80
forval x = 2004/2007 {
	pwcorr icas sigacts_s1 if year==`x'
	}


************************************************************************
* Part 6
************************************************************************

* Repeat site analysis dropping intermediate towers - not in paper but good to see
use fullbuffers_20_15_4_12_working_new.dta, clear

areg eventcount_S1 after aftnew10 q_5-q_24 if propnew==0 | propnew>=.1, cluster(siteid) a(siteid)	 	
outreg2 using tow_difindif_qfe_nointermediatezero, replace auto(3) less(1) ctitle("10") excel drop(q_*)
forval x = 2/9 {
	display "Dif-in-dif with site and quarter FE"	
	areg eventcount_S1 after aftnew`x'0 q_5-q_24 if propnew==0 | propnew>=.`x' , cluster(siteid) a(siteid) 	
	outreg2 using tow_difindif_qfe_nointermediatezero, auto(3) less(1) ctitle("`x'0") excel drop(q_*)
	}
	

